@@ -214,7 +214,7 @@ MriImage <- setRefClass("MriImage", contains="SerialisableObject", fields=list(i
         }
         else
         {
-            indices <- alist(x=,y=,z=,t=,u=,v=,w=)[seq_along(imageDims)]
+            indices <- alist(i=,j=,k=,t=,u=,v=,w=)[seq_along(imageDims)]
             indices[dim] <- loc
             newData <- do.call("[", c(list(data),indices))
             if (is.vector(newData))
@@ -397,76 +397,6 @@ setAs("MriImage", "array", function (from) as(from$getData(),"array"))
 
 setAs("array", "MriImage", function (from) asMriImage(from))
 
-setAs("MriImage", "nifti", function (from) {
-    if (is.null(getOption("niftiAuditTrail")))
-        options(niftiAuditTrail=FALSE)
-    loadNamespace("oro.nifti")
-    
-    if (from$isEmpty())
-    {
-        datatype <- list(code=2, type="integer", size=1, isSigned=FALSE)
-        data <- array(0L, dim=from$getDimensions())
-    }
-    else
-    {
-        datatype <- chooseDataTypeForImage(from, "Nifti")
-        data <- as(from$getData(), "array")
-    }
-    
-    # We default to 10 (mm and s)
-    unitName <- from$getVoxelUnits()
-    unitCode <- as.numeric(.Nifti$units[names(.Nifti$units) %in% unitName])
-    if (length(unitCode) == 0)
-        unitCode <- 10
-    else
-        unitCode <- sum(unitCode)
-    
-    nDims <- from$getDimensionality()
-    fullDims <- c(nDims, abs(from$getDimensions()), rep(1,7-nDims))
-    fullVoxelDims <- c(-1, abs(from$getVoxelDimensions()), rep(0,7-nDims))
-    
-    xform <- from$getXform()
-    sformRows <- c(xform[1,], xform[2,], xform[3,])
-    quaternion <- xformToQuaternion(xform)
-    fullVoxelDims[1] <- quaternion$handedness
-    xformCode <- ifelse(from$getDimensionality() == 2, 0, 2)
-    
-    return (new(structure("nifti",package="oro.nifti"), .Data=data, dim_=fullDims, datatype=datatype$code, bitpix=8*datatype$size, pixdim=fullVoxelDims, xyzt_units=unitCode, qform_code=xformCode, sform_code=xformCode, quatern_b=quaternion$q[2], quatern_c=quaternion$q[3], quatern_d=quaternion$q[4], qoffset_x=quaternion$offset[1], qoffset_y=quaternion$offset[2], qoffset_z=quaternion$offset[3], srow_x=sformRows[1:4], srow_y=sformRows[5:8], srow_z=sformRows[9:12], cal_min=min(data), cal_max=max(data)))
-})
-
-setAs("nifti", "MriImage", function (from) {
-    if (is.null(getOption("niftiAuditTrail")))
-        options(niftiAuditTrail=FALSE)
-    loadNamespace("oro.nifti")
-    
-    nDims <- from@dim_[1]
-    voxelDims <- from@pixdim[seq_len(nDims)+1]
-    voxelDims3D <- c(voxelDims, rep(0,max(0,3-nDims)))[1:3]
-    
-    spatialUnitCode <- packBits(intToBits(from@xyzt_units) & intToBits(7), "integer")
-    temporalUnitCode <- packBits(intToBits(from@xyzt_units) & intToBits(24), "integer")
-    voxelUnit <- names(.Nifti$units)[.Nifti$units %in% c(spatialUnitCode,temporalUnitCode)]
-    if (length(voxelUnit) == 0)
-        voxelUnit <- NULL
-    
-    if (from@qform_code > 0)
-    {
-        xform <- quaternionToXform(c(from@quatern_b,from@quatern_c,from@quatern_d))
-        xform[1:3,4] <- c(from@qoffset_x, from@qoffset_y, from@qoffset_z)
-        qfactor <- sign(from@pixdim[1] + 0.1)
-        xform[1:3,1:3] <- xform[1:3,1:3] * rep(c(abs(voxelDims3D[1:2]), qfactor*abs(voxelDims[3])), each=3)
-    }
-    else if (from@sform_code > 0)
-        xform <- rbind(from@srow_x, from@srow_y, from@srow_z, c(0,0,0,1))
-    else
-        xform <- diag(c(-1, 1, 1, 1))
-    
-    origin <- c(1-xform[1:3,4]/voxelDims3D, rep(0,max(0,3-nDims)))
-    
-    image <- MriImage$new(imageDims=from@dim_[seq_len(nDims)+1], voxelDims=voxelDims, voxelDimUnits=voxelUnit, origin=origin, storedXform=xform, reordered=FALSE, data=from@.Data)
-    return (image)
-})
-
 .warnIfIndexingUnreorderedImage <- function (image)
 {
     # The argument is an unreordered image and contains a non-LAS xform
