@@ -44,7 +44,7 @@ readAnalyze <- function (fileNames)
     invisible (list(imageMetadata=imageMetadata, storageMetadata=storageMetadata))
 }
 
-writeMriImageToAnalyze <- function (image, fileNames, gzipped = FALSE)
+writeAnalyze <- function (image, fileNames, gzipped = FALSE)
 {
     if (!is(image, "MriImage"))
         report(OL$Error, "The specified image is not an MriImage object")
